import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');

const projection = geoMercator()
  .translate([-1780, 1050])
  .scale([100]);
const pathGenerator = geoPath().projection(projection);

const colorScale = scaleOrdinal(schemeCategory10);

json(
  'https://raw.githubusercontent.com/wmgeolab/geoBoundaries/6b1d1e655cc4d67c9bbbc86fd0d53cffbfcf3641/releaseData/gbOpen/KAZ/ADM0/geoBoundaries-KAZ-ADM0.topojson'
).then((data) => {
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
countryShapes.features.shift()
 //countryShapes.features.forEach((d) => console.log(d.properties)  );
 
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

svg
  .selectAll('text')
  .data(countryShapes.features)
  .enter()
  .append('text')
  .text((d) => d.properties.NAME_1)
  .attr('x', d=>  pathGenerator.centroid(d)[0]   )
  .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
   .attr("font-size", "15px");
});